Expression.V2.Context
(expression v2.49.0)
The context supplied to a function generated by Expression.V2.Compile.compile/1
This will be expanded with support for more attributes that a callback function can access but normal Expression evaluation can not.